function DrawingManager(map, opts) {

    try {
        L;
    } catch (e) {
        throw Error('Leaflet Map JS API is not ready yet!');
    }

    const me = this;

    let drawModeMarker = "marker";
    let DrawModeCircle = "circle";
    let DrawModeArea = "area";
    let DrawModeFitBounds = "fitbounds";
    let DrawModeReset = "reset";

    me.map = map;
    me._opts = opts;
    me._drawingType = null;
    me._mapclick = true;
    me.markerOptions = opts.markerOptions || {};
    me.circleOptions = opts.circleOptions || {};
    me.areaOptions = opts.areaOptions || {};
    me.isDraw = false;
    me.radius = opts.circleOptions.radius;
    me.vertex = [];
    me.vertexCount = 0;
    me.polygonArea = new Map();
    me.isMoreArea = opts.areaOptions.isMoreArea || false;
    me.squareArea = opts.areaOptions.areaMaxSquare || 1400;
    me.isRedraw = null;
    me.mode = opts.activeMode;

    me.extend(DrawingManager, L.Class.extend({

        setDrawingMode: function (drawingType, opts) {
            const me = this;
            me.markerOptions = opts.markerOptions || {};
            me.circleOptions = opts.circleOptions || {};
            me.areaOptions = opts.areaOptions || {};
            me.isDraw = opts.isDraw;
            me.isRedraw = opts.isRedraw;
            me.radius = opts.circleOptions.radius;
            me.mode = opts.activeMode;

            const eventMode = {
                isRedraw: opts.isRedraw,
                isDraw: opts.isDraw,
                mode: me.mode,
            }

            me.map.fire('draw:mode', { eventMode });


            if (me.markerOptions.markerLatitude && me.markerOptions.markerLongitude) {
                me.setPosition(me.markerOptions.markerLatitude, me.markerOptions.markerLongitude);
            }


            if (me.areaOptions) {
                me.areaCoordinates = me.areaOptions.areaCoordinates;
            }

            switch (drawingType) {
                case drawModeMarker:
                    me._bindMarker(false);
                    break;
                case DrawModeCircle:
                    me._bindMarker(true);
                    break;
                case DrawModeArea:
                    me._bindArea();
                    break;
                case DrawModeFitBounds:
                    me._fitBounds();
                case DrawModeReset:
                    me.reset();
                    break;
                default:
                    me._remove();
                    break;
            }
            me._drawingType = drawingType;

        },

        reset: function () {
            const me = this;
            me.map.removeEventListener('click');
            me.map.removeEventListener('mousedown');
            me.isRedraw = false;
        },

        remove: function () {
            const me = this;
            me.isRedraw = false;
            me._remove();
        },

        resetMarker: function () {
            const me = this;
            me._centerMarker && me._removeCenterMarker();
        },

        isAnimateMarker: function (enabled) {
            try {
                const me = this;
                me._centerMarker && me._centerMarker._icon.classList.add('poi');
            } catch { }
        },

        _fitBounds: function () {
            const me = this;
            me._centerMarker && me._fitBoundsMarker();
            me._area && me._fitBoundsArea();
            me._circle && me._fitBoundsCircle();
        },

        _remove: function () {
            const me = this;
            me._circle && me._removeCircle();
            me._area && me._removeArea();
            me.polygonArea.length && me._removeArea();
            me._centerMarker && me._removeCenterMarker();
            me.map.removeEventListener('click');
        },

        _bindMarker: function (enabledCircle) {

            const me = this;
            me.map.off('mousedown');
            me.map.removeEventListener('click');
            me.map.off('click', me.createCenterMarker)
            me._removeCircle();
            me._removeCenterMarker();
            me._removeArea();

            me.createCenterMarker = (e) => {
                me._removeCircle();
                me._removeCenterMarker();

                e && me._setPosition(e);
                if (!me.position) { return; }

                me._centerMarker = new L.marker(me.position, { draggable: false, icon: me._getIcon(enabledCircle), zIndexOffset: 1000, autoPan: true });

                me.map.addLayer(me._centerMarker);
                !enabledCircle && me.map.fire('draw:marker_create', me._getPosition());

                me._centerMarker.getElement().style.cursor = 'pointer';
                me.position = null;



                if (me.markerOptions.fitBounds && !enabledCircle) { me._fitBoundsMarker(); }
                me.markerOptions.isMarkerAnimate && !enabledCircle && me.isAnimateMarker(true);
                enabledCircle && me._bindCircle();

                me._centerMarkerAddEventListener();

            }

            if (!this.isDraw) {
                me.createCenterMarker();
                me.map.removeEventListener('click');
            }


            me.map.on('click', (event) => {

                if (me.isDraw || me.isRedraw) {
                    L.DomEvent.stopPropagation(event);
                    me.createCenterMarker(event);
                }
                else {
                    me.map.off('click', me.createCenterMarker)
                    me.map.removeEventListener('click');
                }

            });
        },

        _getIcon: function (flag) {
            const me = this;
            if (flag) {
                return L.icon({
                    iconUrl: me.circleOptions.iconUrl,
                    iconAnchor: [10, 30]
                });
            } else {
                return L.divIcon({
                    iconSize: [24, 33],
                    className: 'marker-icon',
                    iconAnchor: [10, 22],
                    html: `<img src='${me.markerOptions.iconUrl}'/>`,
                });
            }

        },

        _bindCircle: function () {

            const me = this;

            if (me._circle) {
                me.map.removeLayer(me._circle);
                me.map.removeLayer(me._vertexMarker);
                me.map.fire('draw:circle_remove', null);
            }

            me._vertexMarkerCopy && me.map.removeLayer(me._vertexMarkerCopy);

            if (me._centerMarker) {
                me._circle = new L.circle(me._centerMarker.getLatLng(), {
                    color: me.circleOptions.fillColor,
                    fillOpacity: me.circleOptions.fillOpacity,
                    opacity: me.circleOptions.strokeOpacity,
                    radius: me.circleOptions.radius,
                    strokeColor: me.circleOptions.strokeColor,
                    bubblingMouseEvents: false,
                    weight: me.circleOptions.strokeWeight,
                    radius: Math.floor(me.radius)
                });

                me.map.addLayer(me._circle);
                me._fitBoundsCircle();
                me._centerMarker.getElement().style.cursor = 'move';
                me._centerMarker.setZIndexOffset(99999);
                me._centerMarker.dragging.enable();
                me._setIconMarker(me.circleOptions.iconUrl);

                me._createVertexMarker();
                me._createVertexMarkerCopy();

                me._circle.on('mouseover', () => { me.map.off('click'); });

                me._circle.on('mouseout', () => { if (me.isDraw || me.isRedraw) { me.map.on('click', me.createCenterMarker) }; });

            }
        },

        _bindArea: function () {

            const me = this;
            me.map.removeEventListener('click');

            !me.isMoreArea && me._removeArea();

            me._removeCircle();
            me._removeCenterMarker();

            if (me.isMoreArea && me.polygonArea.size === 5) { return false };
            let createArea = () => {

                !me.isMoreArea && me._removeArea();

                let patchLatLngArea = [];

                me._setDrawing(false);

                const options = {
                    strokeColor: me.areaOptions.strokeColor,
                    opacity: me.areaOptions.strokeOpacity,
                    color: me.areaOptions.fillColor,
                    fillOpacity: me.areaOptions.fillOpacity,
                    weight: me.areaOptions.strokeWeight,
                }

                me._area = new L.polyline([], options).addTo(me.map);

                me.map.on('mousemove', (event) => {
                    if (typeof event.latlng !== "undefined") {
                        patchLatLngArea.push(event.latlng)
                        const area = me.geodesicArea(patchLatLngArea);
                        me.map.getContainer().style.cursor = 'not-allowed';
                        if (area < me.squareArea * 1000000) {
                            me._area.setLatLngs(patchLatLngArea);
                            me.map.getContainer().style.cursor = 'crosshair';
                            return false;
                        }
                    }
                });

                document.addEventListener('mouseup', () => {
                    me.map.off('mousemove');
                    let path = me._area.getLatLngs();
                    me._setDrawing(true);
                    me.map.removeLayer(me._area);
                    if (!path.length) { return false };
                    me._area = new L.polygon(path, options).addTo(me.map);
                    me.vertexCount++;
                    me.polygonArea.set(me.vertexCount, me._area);
                    me.map.off('mousedown');


                    me._fitBoundsArea(path);

                    if (me.isMoreArea) {
                        patchAreaLatLng = path;
                        let patchAreaLatLngMax = me.findRoundPoints(patchAreaLatLng, 0.001);
                        if (patchAreaLatLngMax) {
                            if (patchAreaLatLngMax.length == 0) {
                                patchAreaLatLngMax = me.findRoundPoints(patchAreaLatLng, 0.01);
                            }
                            if (patchAreaLatLngMax.length == 0) {
                                patchAreaLatLngMax = me.findRoundPoints(patchAreaLatLng, 1);
                            }
                            if (patchAreaLatLngMax.length == 0) {
                                patchAreaLatLngMax = patchAreaLatLng;
                            }
                        }

                        var pointSelect = null;
                        var pointSelect = patchAreaLatLngMax[0];

                        for (var n = 0; n < patchAreaLatLngMax.length; n++) {
                            let item = patchAreaLatLngMax[n];
                            if (item.lng > pointSelect.lng) {
                                pointSelect = item;
                            }
                        }

                        me.createVertexArea(pointSelect);
                    }

                }, { once: true });
            }

            if (this.isDraw) {
                this.map.on('mousedown', (e) => {
                    e = window.event || e;
                    if (e.button == 2) { return; }
                    createArea();
                });
            }
            else {
                me._redrawArea()
            }
        },

        geodesicArea: function (latLngs) {
            var pointsCount = latLngs.length,
                area = 0.0,
                d2r = Math.PI / 180,
                p1, p2;

            if (pointsCount > 2) {
                for (var i = 0; i < pointsCount; i++) {
                    p1 = latLngs[i];
                    p2 = latLngs[(i + 1) % pointsCount];
                    area += ((p2.lng - p1.lng) * d2r) *
                        (2 + Math.sin(p1.lat * d2r) + Math.sin(p2.lat * d2r));
                }
                area = area * 6378137.0 * 6378137.0 / 2.0;
            }

            return Math.abs(area);
        },

        findRoundPoints: function (patch, round) {
            var result = [];
            var center = me._area.getBounds().getCenter();

            var roundMinLat = center.lat - round;
            var roundMaxLat = center.lat + round;
            for (var n = 0; n < patch.length; n++) {
                let item = patch[n];

                if (item.lat >= roundMinLat && item.lat <= roundMaxLat) {
                    if (item.lng > center.lng) {
                        result.push(item);
                    }
                }
            }

            return result;

        },

        createVertexArea: function (pointSelect) {

            let me = this;
            const icon = L.icon({
                iconUrl: me.areaOptions.areaIconVertex,
                iconAnchor: [7, 10],
                iconSize: [24, 24]
            });

            _vertex = new L.marker(pointSelect, { draggable: false, icon: icon, id: me.vertexCount, }).addTo(me.map);

            _vertex.on('click', function () {
                if (me.polygonArea.get(this.options.id)) {
                    me.map.removeLayer(this);
                    me.map.removeLayer(me.polygonArea.get(this.options.id));
                    me.polygonArea.delete(this.options.id);
                }
                me.map.fire('draw:area_remove', me._convertCoordinates());
            });

            me.vertex.push(_vertex);

        },

        _redrawArea: function () {
            const me = this;
            const latlngs = me._convertlatlngs();
            const options = {
                strokeColor: me.areaOptions.strokeColor,
                opacity: me.areaOptions.strokeOpacity,
                color: me.areaOptions.fillColor,
                fillOpacity: me.areaOptions.fillOpacity,
                strokeWeight: me.areaOptions.strokeWeight,
            }

            me._area = new L.polygon(latlngs, options).addTo(me.map);

            me._fitBoundsArea(latlngs);

        },

        _setIconMarker: function (iconUrl) {
            const me = this;
            if (me._centerMarker) {
                const icon = L.icon({
                    iconUrl: iconUrl,
                    iconAnchor: [10, 30]
                });
                me._centerMarker.setIcon(icon);
            }
        },

        _convertlatlngs: function () {
            const me = this;
            let latlngs = [];

            if (me.areaCoordinates.length > 0) {
                for (var n = 0; n < me.areaCoordinates.length; n++) {
                    let item = me.areaCoordinates[n];
                    let position = new L.LatLng(item.latitude, item.longitude);
                    latlngs.push(position);
                }

                return latlngs;
            }
        },

        _reset: function () {
            const me = this;
            me._removeArea();
            me._removeCenterMarker();
            me._removeCircle();
        },

        _removeCircle: function () {

            const me = this;

            if (me._circle) {
                me.map.removeLayer(me._circle);
                me.map.removeLayer(me._vertexMarker);
                me._circle = null;
                me._vertexMarker = null;
                me.map.fire('draw:circle_remove', null);
            }
            if (me._vertexMarkerCopy) {
                me.map.removeLayer(me._vertexMarkerCopy);
                me._vertexMarkerCopy = null;
            }
        },

        _removeCenterMarker: function () {
            let me = this;
            if (me._centerMarker && !me._circle) {
                me.map.removeLayer(me._centerMarker);
                me._centerMarker = null;
                me.map.fire('draw:marker_remove', null);
            }
        },

        _removeArea: function () {
            const me = this;

            if (me._area) {
                me.map.removeLayer(me._area);
                me._area = null;
                me.map.fire('draw:area_remove', []);

            }

            me.polygonArea.forEach((key) => {
                me.map.removeLayer(key);
            });

            me.vertex.forEach((key) => {
                me.map.removeLayer(key);
            });

            me.polygonArea.clear();
            me.vertex = [];
            me.currentAreaCount = 0;
        },

        _setDrawing: function (enabled) {
            let me = this;
            enabled ? me.map.dragging.enable() : me.map.dragging.disable();
            enabled ? me.map.scrollWheelZoom.enable() : me.map.scrollWheelZoom.disable();
            enabled ? me.map.doubleClickZoom.enable() : me.map.doubleClickZoom.disable();
        },

        _fitBoundsArea: function (latlngs) {
            const me = this;
            if (me._area) {
                me.map.fitBounds(me._area.getBounds());
            }
            me.map.fire('draw:area_create', me._convertCoordinates(latlngs));
        },

        _fitBoundsMarker: function () {
            const me = this;
            me.map.getZoom() > 9 ?
                me.map.setView(me._centerMarker.getLatLng(), me.map.getZoom())
                : me.map.setView(me._centerMarker.getLatLng(), 9);
        },

        _fitBoundsCircle: function () {
            const me = this;
            me.map.fitBounds(me._circle.getBounds());

            me.map.fire('draw:circle_create', me._getInfo());
        },

        _convertCoordinates: function (coordinates) {
            const me = this;
            let positions = [];
            let arrayArea = {};
            let id = null;
            if (!me.isMoreArea) {
                let latLng = [];
                for (var n = 0; n < coordinates.length; n++) {
                    let item = coordinates[n];
                    let position = {
                        latitude: item.lat,
                        longitude: item.lng,
                    }
                    latLng.push(position);
                    position = positions;
                    id = 0;
                }
                positions.push(latLng);
                position = positions[0];

                const pos = me._area.getBounds().getCenter()
                center = {
                    latitude: pos.lat,
                    longitude: pos.lng,
                }

                eventArea = {
                    id: id,
                    position,
                    positions,
                    center,
                    zoom: me.map.getZoom(),

                }
                return { eventArea };

            } else {
                me.polygonArea.forEach((key, value) => {
                    let latLng = [];
                    for (var n = 0; n < key._latlngs[0].length; n++) {
                        let item = key._latlngs[0][n];
                        let pos = {
                            latitude: item.lat,
                            longitude: item.lng,
                        }
                        latLng.push(pos);
                        id = value;
                    }
                    positions.push(latLng);
                });

                arrayArea = {
                    id: id,
                    positions,
                }
                return { arrayArea };
            }

        },

        _getPosition: function () {
            const me = this;
            if (me._centerMarker) {

                const position = {
                    latitude: me._centerMarker.getLatLng().lat,
                    longitude: me._centerMarker.getLatLng().lng
                };
                const eventMarker = {
                    isDraw: me.isDraw,
                    position,
                    placeId: null
                }
                return { eventMarker };
            }
        },

        setEnableDraw: function (enabled) {
            this.isDraw = enabled;
        },

        destination: function (latlng, heading, distance) {
            heading = (heading + 360) % 360;
            var rad = Math.PI / 180,
                radInv = 180 / Math.PI,
                R = 6378137,
                lon1 = latlng.lng * rad,
                lat1 = latlng.lat * rad,
                rheading = heading * rad,
                sinLat1 = Math.sin(lat1),
                cosLat1 = Math.cos(lat1),
                cosDistR = Math.cos(distance / R),
                sinDistR = Math.sin(distance / R),
                lat2 = Math.asin(sinLat1 * cosDistR + cosLat1 *
                    sinDistR * Math.cos(rheading)),
                lon2 = lon1 + Math.atan2(Math.sin(rheading) * sinDistR *
                    cosLat1, cosDistR - sinLat1 * Math.sin(lat2));
            lon2 = lon2 * radInv;
            lon2 = lon2 > 180 ? lon2 - 360 : lon2 < -180 ? lon2 + 360 : lon2;
            return L.latLng([lat2 * radInv, lon2]);
        },

        _setPosition: function (event) {
            const me = this;
            me.position = null;
            if (event) {
                me.position = event.latlng;
            }
        },

        setPosition: function (latitude, longitude) {

            const me = this;
            me.position = null;
            me.position = new L.LatLng(latitude, longitude);
        },

        _createVertexMarker: function () {
            var to = this.destination(this._centerMarker.getLatLng(), 90, this.radius);
            const svg = [
                '<?xml version="1.0"?>',
                '<svg width="15px" height="15px" viewBox="0 0 100 100" version="1.1" xmlns="http://www.w3.org/2000/svg">',
                '<circle stroke="#003dd9" fill="white" stroke-width="10" cx="50" cy="50" r="35"/>',
                '</svg>'
            ].join('\n');

            const icon = L.icon({
                iconUrl: 'data:image/svg+xml;charset=UTF-8,' + encodeURIComponent(svg),
                iconAnchor: [7, 10],
                iconSize: [15, 15]
            });

            this._vertexMarker = new L.marker(to, { draggable: true, icon: icon, zIndexOffset: 100 }).addTo(this.map);
            this._vertexMarker.getElement().style.cursor = 'col-resize';
            me._centerMarker && this._vertexMarkerAddEventListener();
        },

        _vertexMarkerAddEventListener: function () {

            const me = this;
            me.isMaxDistance = false;

            me._vertexMarker.on('drag', function (event) {
                if (!me._centerMarker) { return; }
                me.isMaxDistance = false;
                const distance = L.latLng(me._centerMarker.getLatLng()).distanceTo(event.latlng);

                if (distance >= me.circleOptions.maxRadius) {

                    me._vertexMarker.getElement().style.display = 'none';
                    me._vertexMarker.setZIndexOffset(100);
                    if (me._vertexMarkerCopy) {
                        me._vertexMarkerCopy.getElement().style.display = 'block';
                        me._vertexMarkerCopy.setZIndexOffset(200);
                    }

                    me.map.off('click');
                    me.isMaxDistance = true;
                    me.map.getContainer().style.cursor = 'not-allowed';
                    me.map.fire('draw:circle_radius_max', null);
                    return false;

                }

                me.radius = distance;


                me._circle && me._circle.setRadius(distance);
                me._vertexMarkerCopy && me.map.removeLayer(me._vertexMarkerCopy);
                !me.isMaxDistance && me._createVertexMarkerCopy();


                me._vertexMarker.getElement().style.display = 'block';
                me._vertexMarker.setZIndexOffset(200);

                if (me._vertexMarkerCopy) {
                    me._vertexMarkerCopy.getElement().style.display = 'none';
                    me._vertexMarkerCopy.setZIndexOffset(100);
                }

                const px = me.map.latLngToContainerPoint(event.latlng);
                const pixel = {
                    clientX: px.x,
                    clientY: px.y
                }

                let eventCircle = {
                    pixel,
                    isDraw: me.isDraw,
                    radius: Math.floor(me._circle.getRadius()),

                }

                me._vertexMarker.on('mouseover', () => {
                    if (me._vertexMarkerCopy) {
                        me._vertexMarkerCopy.getElement().style.display = 'none';
                        me._vertexMarker.getElement().style.display = 'block';
                    }

                });

                if (me._vertexMarkerCopy) {
                    me._vertexMarkerCopy.on('mouseover', () => {
                        me._vertexMarker.getElement().style.display = 'block';
                        me._vertexMarkerCopy.getElement().style.display = 'none';
                    })
                }

                me.map.fire('draw:circle_radius_change', { eventCircle });
            });

            me._vertexMarker.on('dragend', () => {
                me.map.getContainer().style.cursor = 'default';
                if (me._vertexMarkerCopy) {
                    if (me.isMaxDistance) {
                        me._vertexMarker.setLatLng(me._vertexMarkerCopy.getLatLng());
                        me._vertexMarker.setZIndexOffset(200);
                        me._vertexMarker.getElement().style.display = 'none';
                        if (me._vertexMarkerCopy) {
                            me._vertexMarkerCopy.setZIndexOffset(100);
                            me._vertexMarkerCopy.getElement().style.display = 'block';
                        }
                    }
                }
                me.map.fire('draw:circle_radius_complete', me._getInfo());


                setTimeout(() => {
                    if (me.isDraw || me.isRedraw) {
                        me.map.on('click', me.createCenterMarker)
                    }
                }
                    , 500);

            });
        },

        _createVertexMarkerCopy: function () {
            let me = this;
            let svg = [
                '<?xml version="1.0"?>',
                '<svg width="15px" height="15px" viewBox="0 0 100 100" version="1.1" xmlns="http://www.w3.org/2000/svg">',
                '<circle stroke="#003dd9" fill="white" stroke-width="10" cx="50" cy="50" r="35"/>',
                '</svg>'
            ].join('\n');

            const icon = L.icon({
                iconUrl: 'data:image/svg+xml;charset=UTF-8,' + encodeURIComponent(svg),
                iconAnchor: [7, 10],
                iconSize: [15, 15]
            });

            me._vertexMarkerCopy = new L.marker(me._vertexMarker.getLatLng(), { draggable: true, icon: icon }).addTo(me.map);
            me._vertexMarkerCopyAddEventListener();
        },

        _vertexMarkerCopyAddEventListener: function () {
            let me = this;
            me._vertexMarkerCopy.on('mouseover', () => {
                me._vertexMarkerCopy.getElement().style.display = 'none';
                me._vertexMarkerCopy.setZIndexOffset(100);
                me._vertexMarker.getElement().style.display = 'block';
                me._vertexMarker.setZIndexOffset(200);

            });

        },

        _centerMarkerAddEventListener: function () {
            const me = this;
            me._centerMarker.on('click', () => {
                me.map.fire('draw:marker_click', me._getPosition());
            });

            me._centerMarker.on('drag', (event) => {
                if (me._vertexMarkerCopy) {
                    me._vertexMarkerCopy.getElement().style.display = 'none';
                    me._vertexMarker.getElement().style.display = 'block';
                }

                me._circle.setLatLng(event.latlng);

                let to = me.destination(event.latlng, 90, me.radius);
                if (me._vertexMarker) {
                    me._vertexMarker.setLatLng(to);
                }

                if (me._vertexMarkerCopy) {
                    me._vertexMarkerCopy.setLatLng(to);
                }

                me._vertexMarker.getElement().style.display = 'none';
                me.map.fire('draw:circle_centre_change', me._getInfo());
            });

            me._centerMarker.on('dragend', () => {
                me._vertexMarker.getElement().style.display = 'block';
                me.map.fire('draw:circle_center_complete', me._getInfo());
            });

            me._centerMarker.on('mouseover', (event) => {

                const px = me.map.latLngToContainerPoint(event.latlng);
                const pixel = {
                    clientX: px.x,
                    clientY: px.y
                }

                const position = {
                    latitude: me._centerMarker.getLatLng().lat,
                    longitude: me._centerMarker.getLatLng().lng
                }

                const eventMarker = {
                    clientX: px.x,
                    clientY: px.y,
                    position
                }

                me.map.fire('draw:marker_mouseover', { eventMarker });
                me.map.off('click');

            });

            me._centerMarker.on('mouseout', () => {
                me.map.fire('draw:marker_mouseout');
                me.map.on('click', me.createCenterMarker);
            });
        },

        _getInfo: function () {
            const me = this;
            if (me._circle) {
                const position = {
                    latitude: me._centerMarker && me._centerMarker.getLatLng().lat || me._circle.getLatLng().lat,
                    longitude: me._centerMarker && me._centerMarker.getLatLng().lng || me._circle.getLatLng().lng
                }
                const eventCircle = {
                    isDraw: me.isDraw,
                    bounds: me._circle.getBounds(),
                    radius: Math.floor(me._circle.getRadius()),
                    position,
                    zoom: me.map.getZoom(),
                };
                return { eventCircle };
            }
        },

        _getZoom: function () {

            let me = this;
            let zoom = {
                zoom: me.map.getZoom()
            }
            return zoom;
        },

        onAdd: function (map) {
            this._map = map;
        },

        addTo: function (map) {
            map.addLayer(this);
            return this;
        },
    }));
}

DrawingManager.prototype.extend = function (obj1, obj2) {
    return (function (object) {
        var property;
        for (property in object.prototype) {
            this.prototype[property] = object.prototype[property];
        }
        return this;
    }).apply(obj1, [obj2]);
};

if (typeof module == 'object') {
    module.exports = { default: DrawingManager, DrawingManager: DrawingManager };
}